@@ -1,8 +1,14 @@
-class Joke():
+
+
+class Overload_Joke():
     
     def __init__(self):
         self.phrase = "phrase"
         
     def joke(self):
         return ("Why this not work?")
-    
\ No newline at end of file
+
+class Autism():
+
+    def brah(self):
+        return("wtf") 
\ No newline at end of file
